import axios from 'axios'
import {getToken} from './auth'
import errorCode from '../config/error-code'
import config from "@/config";
import useUserStore from "@/stores/modules/user";

axios.defaults.headers['Content-Type'] = 'application/json;charset=utf-8'

axios.defaults.withCredentials = true;

//返回其他状态码
axios.defaults.validateStatus = function (status) {
  return status >= 200 && status <= 500;
};

// 创建axios实例
const request = axios.create({
  // axios中请求配置有baseURL选项，表示请求URL公共部分
  baseURL: import.meta.env.VITE_APP_BASE_API,
  // 超时
  timeout: 10000
})
// 请求拦截器
request.interceptors.request.use(
  cfg => {
    cfg.headers['Authorization'] = config.authHeader;
    if (getToken()) {
      cfg.headers[config.TOKEN_HEADER] = 'Bearer ' + getToken()
    }
    return cfg
  },
  error => Promise.reject(error)
)

// 响应拦截器
request.interceptors.response.use(
  res => {
    // 如果返回二进制数据，则不做处理
    const responseTypes = ['blob', 'arraybuffer']
    if (responseTypes.includes(res.request.responseType)) return res.data
    const code = res.data.code || res.data.error_code || 200
    const msg = res.data.message || res.data.msg || res.data.error_description || errorCode[code] || errorCode['default']
    if (code === 401) {
      const userStore = useUserStore()
      userStore.logout().then(() => {
        //清理缓存
        window.localStorage.clear();
        // let pathUrl = window.location.href;
        // localStorage.setItem('USER_INIT_PATH', pathUrl);
        // resetRouter();
        //刷新跳转到登录页
        window.location.href = './';
      });
      return false;
    }
    if (code !== 200) {
      ElMessage.error(msg)
      return Promise.reject(new Error(msg))
    }
    return res.data
  },
  err => {
    return Promise.reject(err)
  }
)

export default request
